==> lxd-5.20-1-aarch64.pkg.tar.xz: usr/share/doc/lxd/getting_started.md <==
---
relatedlinks: https://www.youtube.com/watch?v=QyXOOE_4cm0
---

(getting-started)=
# Getting started

To get started with LXD, see the documentation in this section.

```{filtered-toctree}
:maxdepth: 1

:diataxis:Access the documentation </howto/access_documentation>
:diataxis:Access the UI </howto/access_ui>
:diataxis:Contribute to LXD </contributing>
:diataxis:Get support </support>
:diataxis:Initialize LXD </howto/initialize>
:diataxis:Install LXD </installing>
:diataxis:Manage the snap </howto/snap>
```

In addition, the following clip gives a quick and easy introduction for standard use cases:

<div>
 <script id="asciicast-226224" src="https://asciinema.org/a/226224.js" async></script>
</div>

You can also find a series of demos and tutorials on YouTube:

<iframe width="560" height="315" src="https://www.youtube.com/embed/videoseries?list=PLddduKsl-KEhleT9VTR4hbtlNdtMr6cFd" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

## Related topics

```{only} diataxis
{{getting_started_tut}}

{{getting_started_exp}}

{{getting_started_ref}}
```

```{filtered-toctree}
:maxdepth: 1

:topical:/tutorial/first_steps
:topical:/explanation/containers_and_vms
:topical:/requirements
:topical:Install LXD </installing>
:topical:Initialize LXD </howto/initialize>
:topical:Manage the snap </howto/snap>
:topical:Access the UI </howto/access_ui>
:topical:Access the documentation </howto/access_documentation>
:topical:Frequently asked </faq>
:topical:Contribute to LXD </contributing>
:topical:Get support </support>
```

==> lxd-6.4-1-aarch64.pkg.tar.xz: usr/share/doc/lxd/getting_started.md <==
---
relatedlinks: "[Running&#32;LXD&#32;in&#32;production&#32;-&#32;YouTube](https://www.youtube.com/watch?v=QyXOOE_4cm0)"
---

(getting-started)=
# Getting started

To get started with LXD, see the documentation in this section.

```{only} diataxis
How to install and initialize LXD:
```

```{filtered-toctree}
:maxdepth: 1

:diataxis:Install LXD </installing>
:diataxis:Initialize LXD </howto/initialize>
:diataxis:Manage the snap </howto/snap>
```

```{only} diataxis
How to enable access to the UI and the documentation:
```

```{filtered-toctree}
:maxdepth: 1

:diataxis:Access the UI </howto/access_ui>
:diataxis:Access documentation </howto/access_documentation>
```

```{only} diataxis
How to get support:
```

```{filtered-toctree}
:maxdepth: 1

:diataxis:Get support </support>
```

In addition, the following clip gives a quick and easy introduction for standard use cases:

<div>
 <script id="asciicast-226224" src="https://asciinema.org/a/226224.js" async></script>
</div>

You can also find a series of demos and tutorials on YouTube:

<iframe width="560" height="315" src="https://www.youtube.com/embed/videoseries?list=PLddduKsl-KEhleT9VTR4hbtlNdtMr6cFd" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

## Related topics

```{only} diataxis
{{getting_started_tut}}

{{getting_started_exp}}

{{getting_started_ref}}
```

```{filtered-toctree}
:maxdepth: 1

:topical:/tutorial/first_steps
:topical:/explanation/instances
:topical:/requirements
:topical:Install LXD </installing>
:topical:Initialize LXD </howto/initialize>
:topical:Manage the snap </howto/snap>
:topical:Access the UI </howto/access_ui>
:topical:Access the documentation </howto/access_documentation>
:topical:Frequently asked </faq>
:topical:Get support </support>
```
